======
Citing
======

If you are using Capytaine, please cite both following references:

Ancellin and Dias (2019), **Capytaine: a Python-based linear potential flow solver**, Journal of Open Source Software, 4(36), 1341, https://doi.org/10.21105/joss.01341

Babarit and Delhommeau (2015), **Theoretical and numerical aspects of the open source BEM solver NEMOH**, Proceedings of the 11th European Wave and Tidal Energy Conference (EWTEC2015),

or in bibtex form:

.. code-block:: bib

    @article{ancellin_capytaine_2019,
      author  = {Matthieu Ancellin and Fr{\'{e}}d{\'{e}}ric Dias},
      title   = {Capytaine: a {Python-based} linear potential flow solver},
      journal = {Journal of Open Source Software},
      year    = 2019,
      month   = {apr},
      volume  = {4},
      number  = {36},
      pages   = {1341},
      doi     = {10.21105/joss.01341},
      url     = {https://doi.org/10.21105%2Fjoss.01341},
    }

    @inproceedings{babarit_theoretical_2015,
      author    = {Babarit, Aur{\'e}lien and Delhommeau, G{\'e}rard},
      title     = {Theoretical and numerical aspects of the open source {BEM} solver {NEMOH}},
      year      = {2015},
      booktitle = {{Proceedings of the 11th European Wave and Tidal Energy Conference (EWTEC2015)}},
      address   = {Nantes, France}
    }


Forward speed
-------------

If you are using the forward speed feature of Capytaine, please cite the following paper:

Donatini et al., **Implementation of forward speed effects on an open source seakeeping solver**. In 6th MASHCON: International Conference on Ship Manoeuvring in Shallow and Confined Water, 2022

.. code-block:: bib

    @inproceedings{donatini2022implementation,
        title={Implementation of forward speed effects on an open source seakeeping solver},
        author={Donatini, Luca and Herdayanditya, Ivandito and Verao Fernandez, Gael and Pribadi, Ajie Brama Krishna and Lataire, Evert and Delefortrie, Guillaume},
        booktitle={6th MASHCON: International Conference on Ship Manoeuvring in Shallow and Confined Water},
        pages={20--33},
        year={2022},
        organization={Knowledge Centre for Manoeuvring in Shallow and Confined Water}
    }


Source code
-----------

To cite the source code itself, you can use the DOI :code:`10.5281/zenodo.1426306`.
It represents all versions of Capytaine and always points to the most recent version.
If you want to cite a specific version, you can find its own DOI on `Zenodo <http://doi.org/10.5281/zenodo.1426306>`_.
